@@ -3,6 +3,9 @@ import pandas as pd
 import os
 import re
 from collections import defaultdict
+import warnings
+import math
+import numpy as np
 
 class FileLoader():
     '''
@@ -76,10 +79,30 @@ class FileLoader():
                         # this is a dataarray with dims ['pix_x', 'pix_y']+attrs (standardized)
                         # e.g. generated by img = xr.DataArray(img,dims=['pix_x','pix_y'],
                         #      coords={},attrs=headerdict)
-                    data_rows.append(img)
-                    for dim in dims:
-                        dest_coords[dim].append(img.attrs[dim])
+                    is_duplicate = []
                     
+                    try:
+                        reshaped_md = [{key:dest_coords[key][i] for key in dest_coords.keys()} for i in range(len(list(dest_coords.values())[0]))]
+                        # Tyler Martin (tyler.martin@nist.gov) personally claims that the preceding line is the most Pythonic line of code he has
+                        # ever seen, and respectfully submits that he should be declared BDFL on the basis of this line.
+                        # Seriously, all this does is take dest_coords (a dict of lists) and reshape it to a list of dicts, it's just a mess.
+                        
+                        for entry in reshaped_md:
+                            duplicate = True
+                            for key,val in entry.items():
+                                if img.attrs[key] != val:
+                                    duplicate = False
+                            if duplicate:
+                                break
+                    except IndexError:
+                        duplicate=False
+                    if duplicate:
+                        warnings.warn(f'Duplicate image detected while loading... skipping this image {img.attrs}')
+                    else:
+                        data_rows.append(img)
+                        for dim in dims:
+                            dest_coords[dim].append(img.attrs[dim])
+
                 #update_progress(float(nprocessed)/nfiles,prestring="Loading file " + str(nprocessed) + " of "+
                 #    str(nfiles)+" -- "+file)
         #prepare the index...
@@ -103,4 +126,5 @@ class FileLoader():
         index.name = 'system'
         out = xr.concat(data_rows,dim=index)
         out.attrs.update({'dims_unpacked':dims})
+        out = out.assign_coords({'pix_x':np.arange(0,len(out.pix_x)),'pix_y':np.arange(0,len(out.pix_y))})
         return out
\ No newline at end of file
